@@ -10,12 +10,6 @@ pub mod client_event_loop;
 mod client_message_sorter;
 pub mod device;
 
-use client_event_loop::{ButtplugClientEventLoop, ButtplugClientRequest};
-pub use device::{
-  ButtplugClientDevice, ButtplugClientDeviceEvent, ButtplugClientDeviceMessageType, LinearCommand,
-  RotateCommand, VibrateCommand,
-};
-
 use crate::{
   connector::{ButtplugConnector, ButtplugConnectorError, ButtplugConnectorFuture},
   core::{
@@ -32,7 +26,14 @@ use crate::{
     stream::convert_broadcast_receiver_to_stream,
   },
 };
+#[cfg(feature = "server")]
+use crate::server::ButtplugServer;
+use client_event_loop::{ButtplugClientEventLoop, ButtplugClientRequest};
 use dashmap::DashMap;
+pub use device::{
+  ButtplugClientDevice, ButtplugClientDeviceEvent, ButtplugClientDeviceMessageType, LinearCommand,
+  RotateCommand, VibrateCommand,
+};
 use futures::{
   future::{self, BoxFuture},
   Stream,
@@ -277,27 +278,37 @@ impl ButtplugClient {
   #[cfg(feature = "server")]
   pub async fn connect_in_process(
     &self,
-    options: &crate::server::ButtplugServerOptions,
+    server: Option<ButtplugServer>
   ) -> Result<(), ButtplugClientError> {
     use crate::connector::ButtplugInProcessClientConnector;
 
-    let connector = match ButtplugInProcessClientConnector::new_with_options(options) {
-      Ok(conn) => conn,
-      Err(err) => return Err(ButtplugClientError::ButtplugError(err)),
-    };
+    let connector = ButtplugInProcessClientConnector::new(server);
     #[cfg(feature = "btleplug-manager")]
     {
       use crate::server::comm_managers::btleplug::BtlePlugCommunicationManagerBuilder;
       connector
         .server_ref()
+        .device_manager()
         .add_comm_manager(BtlePlugCommunicationManagerBuilder::default())
         .unwrap();
     }
+    #[cfg(feature = "websocket-server-manager")]
+    {
+      use crate::server::comm_managers::websocket_server::websocket_server_comm_manager::WebsocketServerDeviceCommunicationManagerBuilder;
+      connector
+        .server_ref()
+        .device_manager()
+        .add_comm_manager(
+          WebsocketServerDeviceCommunicationManagerBuilder::default().listen_on_all_interfaces(true),
+        )
+        .unwrap();
+    }
     #[cfg(feature = "serial-manager")]
     {
       use crate::server::comm_managers::serialport::SerialPortCommunicationManagerBuilder;
       connector
         .server_ref()
+        .device_manager()
         .add_comm_manager(SerialPortCommunicationManagerBuilder::default())
         .unwrap();
     }
@@ -306,6 +317,7 @@ impl ButtplugClient {
       use crate::server::comm_managers::lovense_connect_service::LovenseConnectServiceCommunicationManagerBuilder;
       connector
         .server_ref()
+        .device_manager()
         .add_comm_manager(LovenseConnectServiceCommunicationManagerBuilder::default())
         .unwrap();
     }
@@ -316,10 +328,12 @@ impl ButtplugClient {
       };
       connector
         .server_ref()
+        .device_manager()
         .add_comm_manager(LovenseHIDDongleCommunicationManagerBuilder::default())
         .unwrap();
       connector
         .server_ref()
+        .device_manager()
         .add_comm_manager(LovenseSerialDongleCommunicationManagerBuilder::default())
         .unwrap();
     }
@@ -328,6 +342,7 @@ impl ButtplugClient {
       use crate::server::comm_managers::xinput::XInputDeviceCommunicationManagerBuilder;
       connector
         .server_ref()
+        .device_manager()
         .add_comm_manager(XInputDeviceCommunicationManagerBuilder::default())
         .unwrap();
     }
