@@ -5,5 +5,5 @@ pub use async_tungstenite::tungstenite::Error as TungsteniteError;
 pub use websocket_client::ButtplugWebsocketClientTransport;
 
 pub use websocket_server::{
-  ButtplugWebsocketServerTransport, ButtplugWebsocketServerTransportOptions,
+  ButtplugWebsocketServerTransport, ButtplugWebsocketServerTransportBuilder,
 };
