@@ -9,21 +9,53 @@ use crate::{
   core::messages::serializer::ButtplugSerializedMessage,
   util::async_manager,
 };
+use futures_timer::Delay;
 use futures::{future::BoxFuture, AsyncRead, AsyncWrite, FutureExt, SinkExt, StreamExt};
-use std::sync::Arc;
+use std::{
+  sync::Arc,
+  time::Duration
+};
 use tokio::net::TcpListener;
 use tokio::sync::{
   mpsc::{Receiver, Sender},
   Mutex, Notify,
 };
 
-#[derive(Default, Clone, Debug)]
-pub struct ButtplugWebsocketServerTransportOptions {
+#[derive(Clone, Debug)]
+pub struct ButtplugWebsocketServerTransportBuilder {
   /// If true, listens all on available interfaces. Otherwise, only listens on 127.0.0.1.
-  pub ws_listen_on_all_interfaces: bool,
-  /// Insecure port for listening for websocket connections. Secure ports were
-  /// removed, but this name was left as is to minimize code breakage.
-  pub ws_insecure_port: u16,
+  listen_on_all_interfaces: bool,
+  /// Insecure port for listening for websocket connections.
+  port: u16,
+}
+
+impl Default for ButtplugWebsocketServerTransportBuilder {
+  fn default() -> Self {
+    Self {
+      listen_on_all_interfaces: false,
+      port: 12345
+    }
+  }
+}
+
+impl ButtplugWebsocketServerTransportBuilder {
+  pub fn listen_on_all_interfaces(&mut self, listen_on_all_interfaces: bool) -> &mut Self {
+    self.listen_on_all_interfaces = listen_on_all_interfaces;
+    self
+  }
+
+  pub fn port(&mut self, port: u16) -> &mut Self {
+    self.port = port;
+    self
+  }
+
+  pub fn finish(&self) -> ButtplugWebsocketServerTransport {
+    ButtplugWebsocketServerTransport {
+      port: self.port,
+      listen_on_all_interfaces: self.listen_on_all_interfaces,
+      disconnect_notifier: Arc::new(Notify::new()),
+    }
+  }
 }
 
 async fn run_connection_loop<S>(
@@ -38,6 +70,10 @@ async fn run_connection_loop<S>(
 
   let (mut websocket_server_sender, mut websocket_server_receiver) = ws_stream.split();
 
+  // Start pong count at 1, so we'll clear it after sending our first ping.
+  let mut pong_count = 1u32;
+  let mut sleep = Delay::new(Duration::from_millis(1000)).fuse();
+
   loop {
     select! {
       _ = disconnect_notifier.notified().fuse() => {
@@ -47,6 +83,21 @@ async fn run_connection_loop<S>(
           return;
         }
       },
+      _ = sleep => {
+        if pong_count == 0 {
+          error!("Cannot no pongs received, considering connection closed.");
+          return;          
+        }
+        pong_count = 0;
+        if websocket_server_sender
+          .send(async_tungstenite::tungstenite::Message::Ping(vec!(0)))
+          .await
+          .is_err() {
+          error!("Cannot send ping to client, considering connection closed.");
+          return;
+        }
+        sleep = Delay::new(Duration::from_millis(1000)).fuse();
+      },
       serialized_msg = request_receiver.recv().fuse() => {
         if let Some(serialized_msg) = serialized_msg {
           match serialized_msg {
@@ -62,6 +113,7 @@ async fn run_connection_loop<S>(
             ButtplugSerializedMessage::Binary(binary_msg) => {
               if websocket_server_sender
                 .send(async_tungstenite::tungstenite::Message::Binary(binary_msg))
+            
                 .await
                 .is_err() {
                 error!("Cannot send binary value to server, considering connection closed.");
@@ -99,6 +151,7 @@ async fn run_connection_loop<S>(
                 }
                 async_tungstenite::tungstenite::Message::Pong(_) => {
                   // noop
+                  pong_count += 1;
                   continue;
                 }
                 async_tungstenite::tungstenite::Message::Binary(_) => {
@@ -124,19 +177,11 @@ async fn run_connection_loop<S>(
 
 /// Websocket connector for ButtplugClients, using [async_tungstenite]
 pub struct ButtplugWebsocketServerTransport {
-  options: ButtplugWebsocketServerTransportOptions,
+  port: u16,
+  listen_on_all_interfaces: bool,
   disconnect_notifier: Arc<Notify>,
 }
 
-impl ButtplugWebsocketServerTransport {
-  pub fn new(options: ButtplugWebsocketServerTransportOptions) -> Self {
-    Self {
-      options,
-      disconnect_notifier: Arc::new(Notify::new()),
-    }
-  }
-}
-
 impl ButtplugConnectorTransport for ButtplugWebsocketServerTransport {
   fn connect(
     &self,
@@ -145,7 +190,7 @@ impl ButtplugConnectorTransport for ButtplugWebsocketServerTransport {
   ) -> BoxFuture<'static, Result<(), ButtplugConnectorError>> {
     let disconnect_notifier = self.disconnect_notifier.clone();
 
-    let base_addr = if self.options.ws_listen_on_all_interfaces {
+    let base_addr = if self.listen_on_all_interfaces {
       "0.0.0.0"
     } else {
       "127.0.0.1"
@@ -153,16 +198,20 @@ impl ButtplugConnectorTransport for ButtplugWebsocketServerTransport {
 
     let request_receiver = Arc::new(Mutex::new(Some(outgoing_receiver)));
 
-    let addr = format!("{}:{}", base_addr, self.options.ws_insecure_port);
+    let addr = format!("{}:{}", base_addr, self.port);
     debug!("Websocket Insecure: Trying to listen on {}", addr);
-    let request_receiver_clone = request_receiver.clone();
-    let response_sender_clone = incoming_sender.clone();
-    let disconnect_notifier_clone = disconnect_notifier.clone();
+    let request_receiver_clone = request_receiver;
+    let response_sender_clone = incoming_sender;
+    let disconnect_notifier_clone = disconnect_notifier;
     let fut = async move {
       // Create the event loop and TCP listener we'll accept connections on.
       let try_socket = TcpListener::bind(&addr).await;
       debug!("Websocket Insecure: Socket bound.");
-      let listener = try_socket.map_err(|e| ButtplugConnectorError::TransportSpecificError(ButtplugConnectorTransportSpecificError::GenericNetworkError(format!("{:?}", e))))?;
+      let listener = try_socket.map_err(|e| {
+        ButtplugConnectorError::TransportSpecificError(
+          ButtplugConnectorTransportSpecificError::GenericNetworkError(format!("{:?}", e)),
+        )
+      })?;
       debug!("Websocket Insecure: Listening on: {}", addr);
       if let Ok((stream, _)) = listener.accept().await {
         info!("Websocket Insecure: Got connection");
