@@ -1,36 +1,29 @@
 // Buttplug Rust Source Code File - See https://buttplug.io for more info.
 //
-// Copyright 2016-2019 Nonpolynomial Labs LLC. All rights reserved.
+// Copyright 2016-2021 Nonpolynomial Labs LLC. All rights reserved.
 //
 // Licensed under the BSD 3-Clause license. See LICENSE file in the project root
 // for full license information.
 
 //! Device specific identification and protocol implementations.
 
+use super::protocol::{
+  add_to_protocol_map, get_default_protocol_map, ButtplugProtocol, TryCreateProtocolFunc,
+};
 use crate::{
   core::{
     errors::{ButtplugDeviceError, ButtplugError},
     messages::{ButtplugDeviceMessageType, DeviceMessageAttributes, DeviceMessageAttributesMap},
   },
   device::Endpoint,
-  util::json::JSONValidator,
 };
-use super::protocol::{ButtplugProtocol, TryCreateProtocolFunc, get_default_protocol_map, add_to_protocol_map};
+use dashmap::DashMap;
 use serde::Deserialize;
 use std::{
   collections::{HashMap, HashSet},
-  mem,
-  sync::Arc
+  sync::Arc,
 };
 use uuid::Uuid;
-use dashmap::DashMap;
-
-static DEVICE_CONFIGURATION_JSON: &str =
-  include_str!("../../buttplug-device-config/buttplug-device-config.json");
-static DEVICE_CONFIGURATION_JSON_SCHEMA: &str =
-  include_str!("../../buttplug-device-config/buttplug-device-config-schema.json");
-static USER_DEVICE_CONFIGURATION_JSON_SCHEMA: &str =
-  include_str!("../../buttplug-device-config/buttplug-user-device-config-schema.json");
 
 // Note: There's a ton of extra structs in here just to deserialize the json
 // file. Just leave them and build extras (for instance,
@@ -58,7 +51,7 @@ impl PartialEq for BluetoothLESpecifier {
           compare_name = &other_name;
         } else if other_name.ends_with('*') {
           wildcard = other_name.clone();
-          compare_name = &name;
+          compare_name = name;
         } else {
           continue;
         }
@@ -82,11 +75,18 @@ impl BluetoothLESpecifier {
       services: HashMap::new(),
     }
   }
+
+  pub fn merge(&mut self, other: BluetoothLESpecifier) {
+    // Add any new names.
+    self.names = self.names.union(&other.names).cloned().collect();
+    // Add new services, overwrite matching services.
+    self.services.extend(other.services);
+  }
 }
 
 #[derive(Deserialize, Debug, Clone)]
 pub struct LovenseConnectServiceSpecifier {
-  exists: bool
+  exists: bool,
 }
 
 impl Default for LovenseConnectServiceSpecifier {
@@ -161,6 +161,35 @@ pub struct USBSpecifier {
   product_id: u16,
 }
 
+#[derive(Deserialize, Debug, Clone)]
+pub struct WebsocketSpecifier {
+  pub names: HashSet<String>,
+}
+
+impl WebsocketSpecifier {
+  pub fn merge(&mut self, other: WebsocketSpecifier) {
+    // Just add the new identifier names
+    self.names.extend(other.names);
+  }
+}
+
+impl PartialEq for WebsocketSpecifier {
+  fn eq(&self, other: &Self) -> bool {
+    if self.names.intersection(&other.names).count() > 0 {
+      return true;
+    }
+    false
+  }
+}
+
+impl WebsocketSpecifier {
+  pub fn new(name: &str) -> WebsocketSpecifier {
+    let mut set = HashSet::new();
+    set.insert(name.to_string());
+    WebsocketSpecifier { names: set }
+  }
+}
+
 #[derive(Deserialize, Debug, PartialEq, Clone)]
 pub enum DeviceSpecifier {
   BluetoothLE(BluetoothLESpecifier),
@@ -169,6 +198,7 @@ pub enum DeviceSpecifier {
   Serial(SerialSpecifier),
   XInput(XInputSpecifier),
   LovenseConnectService(LovenseConnectServiceSpecifier),
+  Websocket(WebsocketSpecifier),
 }
 
 #[derive(Deserialize, Debug, Clone)]
@@ -178,7 +208,7 @@ pub struct ProtocolAttributes {
   messages: Option<DeviceMessageAttributesMap>,
 }
 
-#[derive(Deserialize, Debug, Clone)]
+#[derive(Deserialize, Debug, Clone, Default)]
 pub struct ProtocolDefinition {
   // Can't get serde flatten specifiers into a String/DeviceSpecifier map, so
   // they're kept separate here, and we return them in get_specifiers(). Feels
@@ -188,6 +218,7 @@ pub struct ProtocolDefinition {
   pub serial: Option<Vec<SerialSpecifier>>,
   pub hid: Option<Vec<HIDSpecifier>>,
   pub xinput: Option<XInputSpecifier>,
+  pub websocket: Option<WebsocketSpecifier>,
   #[serde(rename = "lovense-connect-service")]
   pub lovense_connect_service: Option<LovenseConnectServiceSpecifier>,
   pub defaults: Option<ProtocolAttributes>,
@@ -195,13 +226,6 @@ pub struct ProtocolDefinition {
   pub configurations: Vec<ProtocolAttributes>,
 }
 
-#[derive(Deserialize, Debug, Clone)]
-pub struct UserProtocolDefinition {
-  // Right now, we only allow users to specify serial ports through this
-  // interface. It will contain more additions in the future.
-  pub serial: Option<Vec<SerialSpecifier>>,
-}
-
 fn option_some_eq<T>(a: &Option<T>, b: &T) -> bool
 where
   T: PartialEq,
@@ -225,36 +249,84 @@ impl PartialEq<DeviceSpecifier> for ProtocolDefinition {
       DeviceSpecifier::BluetoothLE(other_btle) => option_some_eq(&self.btle, other_btle),
       DeviceSpecifier::HID(other_hid) => option_some_eq_vec(&self.hid, other_hid),
       DeviceSpecifier::XInput(other_xinput) => option_some_eq(&self.xinput, other_xinput),
-      DeviceSpecifier::LovenseConnectService(other_lovense_service) => option_some_eq(&self.lovense_connect_service, other_lovense_service),
+      DeviceSpecifier::Websocket(other_websocket) => {
+        option_some_eq(&self.websocket, other_websocket)
+      }
+      DeviceSpecifier::LovenseConnectService(other_lovense_service) => {
+        option_some_eq(&self.lovense_connect_service, other_lovense_service)
+      }
     }
   }
 }
 
-#[derive(Deserialize, Debug)]
-pub struct ProtocolConfiguration {
-  pub version: u32,
-  pub(self) protocols: HashMap<String, ProtocolDefinition>,
-}
-
-#[derive(Deserialize, Debug)]
-pub struct UserProtocolConfiguration {
-  pub protocols: HashMap<String, UserProtocolDefinition>,
-}
-
-impl ProtocolConfiguration {
-  pub fn merge_user_config(&mut self, other: UserProtocolConfiguration) {
-    // For now, we're only merging serial info in.
-    for (protocol, conf) in other.protocols {
-      if self.protocols.contains_key(&protocol) {
-        let our_serial_conf_option = &mut self.protocols.get_mut(&protocol).unwrap().serial;
-        let mut other_serial_conf = conf.serial;
-        if let Some(ref mut our_serial_config) = our_serial_conf_option {
-          our_serial_config.extend(other_serial_conf.unwrap());
-        } else {
-          mem::swap(our_serial_conf_option, &mut other_serial_conf);
-        }
+impl ProtocolDefinition {
+  pub fn merge_user_definition(&mut self, other: ProtocolDefinition) {
+    // Easy: Just extend vectors we already have
+    if let Some(other_usb) = other.usb {
+      if let Some(ref mut usb) = self.usb {
+        usb.extend(other_usb);
+      } else {
+        self.usb = Some(other_usb);
       }
     }
+
+    if let Some(other_serial) = other.serial {
+      if let Some(ref mut serial) = self.serial {
+        serial.extend(other_serial);
+      } else {
+        self.serial = Some(other_serial);
+      }
+    }
+
+    if let Some(other_hid) = other.hid {
+      if let Some(ref mut hid) = self.hid {
+        hid.extend(other_hid);
+      } else {
+        self.hid = Some(other_hid);
+      }
+    }
+
+    // Not so easy: Actually do complex merges for systems with more identifiers
+    if let Some(other_btle) = other.btle {
+      if let Some(ref mut btle) = self.btle {
+        btle.merge(other_btle);
+      } else {
+        self.btle = Some(other_btle);
+      }
+    }
+
+    if let Some(other_websocket) = other.websocket {
+      if let Some(ref mut websocket) = self.websocket {
+        websocket.merge(other_websocket);
+      } else {
+        self.websocket = Some(other_websocket);
+      }
+    }
+
+    // Not possible: Don't even try to merge specific specifiers.
+    if other.xinput.is_some() {
+      error!("XInput specifier set for user configuration, ignoring.");
+    }
+
+    if other.lovense_connect_service.is_some() {
+      error!("Lovense connect service specifier set for user configuration, ignoring.");
+    }
+
+    // If new defaults are set, overwrite.
+    if other.defaults.is_some() {
+      self.defaults = other.defaults;
+    }
+
+    // Treat configurations like paths; Extend using the new ones first, so we'll find them first,
+    // but leave everything in. Post warning messages if anything repeats after this.
+    if !other.configurations.is_empty() {
+      self.configurations = other
+        .configurations
+        .iter()
+        .chain(self.configurations.iter())
+        .cloned()
+        .collect();
+    }
   }
 }
 
@@ -354,83 +426,39 @@ impl DeviceProtocolConfiguration {
 
 pub struct DeviceConfigurationManager {
   allow_raw_messages: bool,
-  pub(self) config: ProtocolConfiguration,
-  protocol_map: Arc<DashMap<String, TryCreateProtocolFunc>>
+  protocol_definitions: Arc<DashMap<String, ProtocolDefinition>>,
+  protocol_map: Arc<DashMap<String, TryCreateProtocolFunc>>,
 }
 
 impl Default for DeviceConfigurationManager {
   fn default() -> Self {
     // Unwrap allowed here because we assume our built in device config will
     // always work. System won't pass tests or possibly even build otherwise.
-    Self::new_with_options(false, &None, &None).unwrap()
+    Self::new(false)
   }
 }
 
 impl DeviceConfigurationManager {
-  pub fn new_with_options(
-    allow_raw_messages: bool,
-    external_config: &Option<String>,
-    user_config: &Option<String>,
-  ) -> Result<Self, ButtplugDeviceError> {
-    // TODO Handling references incorrectly here.
-    let config_str = if let Some(cfg) = external_config {
-      cfg
-    } else {
-      DEVICE_CONFIGURATION_JSON
-    };
-
-    let config_validator = JSONValidator::new(DEVICE_CONFIGURATION_JSON_SCHEMA);
-    let mut config: ProtocolConfiguration = match config_validator.validate(&config_str) {
-      Ok(_) => match serde_json::from_str(&config_str) {
-        Ok(protocol_config) => protocol_config,
-        Err(err) => {
-          return Err(ButtplugDeviceError::DeviceConfigurationFileError(format!(
-            "{}",
-            err
-          )))
-        }
-      },
-      Err(err) => {
-        return Err(ButtplugDeviceError::DeviceConfigurationFileError(format!(
-          "{}",
-          err
-        )))
-      }
-    };
-    info!(
-      "Successfully loaded Device Configuration File Version {}",
-      config.version
-    );
-
-    if let Some(user_config_str) = user_config {
-      let user_validator = JSONValidator::new(USER_DEVICE_CONFIGURATION_JSON_SCHEMA);
-      match user_validator.validate(&user_config_str) {
-        Ok(_) => match serde_json::from_str(&user_config_str) {
-          Ok(user_cfg) => config.merge_user_config(user_cfg),
-          Err(err) => {
-            return Err(ButtplugDeviceError::DeviceConfigurationFileError(format!(
-              "{}",
-              err
-            )))
-          }
-        },
-        Err(err) => {
-          return Err(ButtplugDeviceError::DeviceConfigurationFileError(format!(
-            "{}",
-            err
-          )))
-        }
-      }
-    }
-
-    Ok(DeviceConfigurationManager {
+  pub fn new(allow_raw_messages: bool) -> Self {
+    Self {
       allow_raw_messages,
-      config,
-      protocol_map: Arc::new(get_default_protocol_map())
-    })
+      protocol_definitions: Arc::new(DashMap::new()),
+      protocol_map: Arc::new(get_default_protocol_map()),
+    }
   }
 
-  pub fn add_protocol<T>(&self, protocol_name: &str) where T: ButtplugProtocol {
+  pub fn add_protocol_definition(&self, protocol_name: &str, protocol_definition: ProtocolDefinition) {
+    self.protocol_definitions.insert(protocol_name.to_owned(), protocol_definition);
+  }
+
+  pub fn remove_protocol_definition(&self, protocol_name: &str) {
+    self.protocol_definitions.remove(protocol_name);
+  }
+
+  pub fn add_protocol<T>(&self, protocol_name: &str)
+  where
+    T: ButtplugProtocol,
+  {
     add_to_protocol_map::<T>(&self.protocol_map, protocol_name);
   }
 
@@ -453,11 +481,11 @@ impl DeviceConfigurationManager {
   /// Provides read-only access to the internal protocol/identifier map. Mainly
   /// used for WebBluetooth filter construction, but could also be handy for
   /// listing capabilities in UI, etc.
-  pub fn protocol_configurations(&self) -> &HashMap<String, ProtocolDefinition> {
-    &self.config.protocols
+  pub fn protocol_definitions(&self) -> Arc<DashMap<String, ProtocolDefinition>> {
+    self.protocol_definitions.clone()
   }
 
-  pub fn find_configuration(
+  pub fn find_protocol_definitions(
     &self,
     specifier: &DeviceSpecifier,
   ) -> Option<(bool, String, ProtocolDefinition)> {
@@ -465,10 +493,10 @@ impl DeviceConfigurationManager {
       "Looking for protocol that matches specifier: {:?}",
       specifier
     );
-    for (name, def) in self.config.protocols.iter() {
-      if def == specifier {
-        info!("Found protocol {:?} for specifier {:?}.", name, specifier);
-        return Some((self.allow_raw_messages, name.clone(), def.clone()));
+    for config in self.protocol_definitions.iter() {
+      if config.value() == specifier {
+        info!("Found protocol {:?} for specifier {:?}.", config.key(), specifier);
+        return Some((self.allow_raw_messages, config.key().clone(), config.value().clone()));
       }
     }
     debug!("No protocol found for specifier {:?}.", specifier);
@@ -479,7 +507,7 @@ impl DeviceConfigurationManager {
     debug!("Looking for protocol {}", name);
     // TODO It feels like maybe there should be a cleaner way to do this,
     // but I'm not really sure what it is?
-    if let Some(proto) = self.config.protocols.get(name) {
+    if let Some(proto) = self.protocol_definitions.get(name) {
       info!("Found a protocol definition for {}", name);
       Some(DeviceProtocolConfiguration::new(
         self.allow_raw_messages,
@@ -496,37 +524,37 @@ impl DeviceConfigurationManager {
 #[cfg(test)]
 mod test {
   use super::{
-    BluetoothLESpecifier, DeviceConfigurationManager, DeviceProtocolConfiguration, DeviceSpecifier,
+    BluetoothLESpecifier, DeviceProtocolConfiguration, DeviceSpecifier, SerialSpecifier
   };
-  use crate::core::messages::ButtplugDeviceMessageType;
-
+  use crate::{core::messages::ButtplugDeviceMessageType, device::configuration_manager::ProtocolDefinition, util::device_configuration::create_test_dcm};
+/*
   #[test]
   fn test_load_config() {
     let config = DeviceConfigurationManager::default();
     debug!("{:?}", config.config);
   }
-
+*/
   #[test]
   fn test_config_equals() {
-    let config = DeviceConfigurationManager::default();
+    let config = create_test_dcm(false);
     let launch = DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("Launch"));
-    assert!(config.find_configuration(&launch).is_some());
+    assert!(config.find_protocol_definitions(&launch).is_some());
   }
 
   #[test]
   fn test_config_wildcard_equals() {
-    let config = DeviceConfigurationManager::default();
+    let config = create_test_dcm(false);
     let lovense =
       DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever"));
-    assert!(config.find_configuration(&lovense).is_some());
+    assert!(config.find_protocol_definitions(&lovense).is_some());
   }
 
   #[test]
   fn test_specific_device_config_creation() {
-    let config = DeviceConfigurationManager::default();
+    let config = create_test_dcm(false);
     let lovense =
       DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever"));
-    let proto = config.find_configuration(&lovense).unwrap();
+    let proto = config.find_protocol_definitions(&lovense).unwrap();
     let proto_config =
       DeviceProtocolConfiguration::new(false, proto.2.defaults.clone(), proto.2.configurations);
     let (name_map, message_map) = proto_config.get_attributes("P", &vec![]).unwrap();
@@ -545,10 +573,10 @@ mod test {
 
   #[test]
   fn test_raw_device_config_creation() {
-    let config = DeviceConfigurationManager::new_with_options(true, &None, &None).unwrap();
+    let config = create_test_dcm(true);
     let lovense =
       DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever"));
-    let proto = config.find_configuration(&lovense).unwrap();
+    let proto = config.find_protocol_definitions(&lovense).unwrap();
     let proto_config =
       DeviceProtocolConfiguration::new(true, proto.2.defaults.clone(), proto.2.configurations);
     let (name_map, message_map) = proto_config.get_attributes("P", &vec![]).unwrap();
@@ -563,10 +591,10 @@ mod test {
 
   #[test]
   fn test_non_raw_device_config_creation() {
-    let config = DeviceConfigurationManager::default();
+    let config = create_test_dcm(false);
     let lovense =
       DeviceSpecifier::BluetoothLE(BluetoothLESpecifier::new_from_device("LVS-Whatever"));
-    let proto = config.find_configuration(&lovense).unwrap();
+    let proto = config.find_protocol_definitions(&lovense).unwrap();
     let proto_config =
       DeviceProtocolConfiguration::new(false, proto.2.defaults.clone(), proto.2.configurations);
     let (name_map, message_map) = proto_config.get_attributes("P", &vec![]).unwrap();
@@ -581,11 +609,11 @@ mod test {
 
   #[test]
   fn test_user_config_loading() {
-    let mut config = DeviceConfigurationManager::default();
-    assert!(config.config.protocols.contains_key("nobra"));
+    // Assume we have a nobra's entry in the device config.
+    let mut config = create_test_dcm(false);
+    assert!(config.protocol_definitions().contains_key("nobra"));
     assert!(config
-      .config
-      .protocols
+      .protocol_definitions()
       .get("nobra")
       .unwrap()
       .serial
@@ -593,8 +621,7 @@ mod test {
       .is_some());
     assert_eq!(
       config
-        .config
-        .protocols
+        .protocol_definitions()
         .get("nobra")
         .unwrap()
         .serial
@@ -603,35 +630,17 @@ mod test {
         .len(),
       1
     );
-    config = DeviceConfigurationManager::new_with_options(
-      false,
-      &None,
-      &Some(
-        r#"
-        { 
-            "protocols": {
-                "nobra": {
-                    "serial": [
-                        {
-                            "port": "COM1",
-                            "baud-rate": 19200,
-                            "data-bits": 8,
-                            "parity": "N",
-                            "stop-bits": 1
-                        }
-                    ]
-                }
-            }
-        }
-        "#
-        .to_string(),
-      ),
-    )
-    .unwrap();
-    assert!(config.config.protocols.contains_key("nobra"));
+
+    // Now try overriding it, make sure we still only have 1.
+    config = create_test_dcm(false);
+    let mut nobra_def = ProtocolDefinition::default();
+    let mut serial_specifier = SerialSpecifier::default();
+    serial_specifier.port = "COM1".to_owned();
+    nobra_def.serial = Some(vec!(serial_specifier));
+    config.add_protocol_definition("nobra", nobra_def);
+    assert!(config.protocol_definitions().contains_key("nobra"));
     assert!(config
-      .config
-      .protocols
+      .protocol_definitions()
       .get("nobra")
       .unwrap()
       .serial
@@ -639,19 +648,17 @@ mod test {
       .is_some());
     assert_eq!(
       config
-        .config
-        .protocols
+        .protocol_definitions()
         .get("nobra")
         .unwrap()
         .serial
         .as_ref()
         .unwrap()
         .len(),
-      2
+      1
     );
     assert!(config
-      .config
-      .protocols
+      .protocol_definitions()
       .get("nobra")
       .unwrap()
       .serial
