@@ -2,6 +2,7 @@
 pub mod aneros;
 pub mod cachito;
 pub mod fleshlight_launch_helper;
+pub mod fredorch;
 pub mod generic_command_manager;
 pub mod jejoue;
 pub mod kiiroo_v2;
@@ -20,6 +21,7 @@ pub mod magic_motion_v1;
 pub mod magic_motion_v2;
 pub mod magic_motion_v3;
 pub mod maxpro;
+pub mod mizzzee;
 pub mod motorbunny;
 pub mod mysteryvibe;
 pub mod nobra;
@@ -38,6 +40,7 @@ pub mod wevibe8bit;
 pub mod xinput;
 pub mod youcups;
 pub mod youou;
+pub mod zalo;
 
 use super::DeviceImpl;
 use crate::{
@@ -53,37 +56,55 @@ use crate::{
     Endpoint,
   },
 };
+use dashmap::DashMap;
 use futures::future::{self, BoxFuture};
 use std::sync::Arc;
-use dashmap::DashMap;
 
-pub type TryCreateProtocolFunc = fn(Arc<DeviceImpl>, DeviceProtocolConfiguration) -> BoxFuture<'static, Result<Box<dyn ButtplugProtocol>, ButtplugError>>;
+pub type TryCreateProtocolFunc =
+  fn(
+    Arc<DeviceImpl>,
+    DeviceProtocolConfiguration,
+  ) -> BoxFuture<'static, Result<Box<dyn ButtplugProtocol>, ButtplugError>>;
 
-pub fn add_to_protocol_map<T>(map: &DashMap<String, TryCreateProtocolFunc>, protocol_name: &str) where T: ButtplugProtocol {
-  map.insert(protocol_name.to_owned(), T::try_create as TryCreateProtocolFunc);
+pub fn add_to_protocol_map<T>(map: &DashMap<String, TryCreateProtocolFunc>, protocol_name: &str)
+where
+  T: ButtplugProtocol,
+{
+  map.insert(
+    protocol_name.to_owned(),
+    T::try_create as TryCreateProtocolFunc,
+  );
 }
 
 pub fn get_default_protocol_map() -> DashMap<String, TryCreateProtocolFunc> {
   let map = DashMap::new();
   add_to_protocol_map::<aneros::Aneros>(&map, "aneros");
   add_to_protocol_map::<cachito::Cachito>(&map, "cachito");
+  add_to_protocol_map::<fredorch::Fredorch>(&map, "fredorch");
   add_to_protocol_map::<jejoue::JeJoue>(&map, "jejoue");
   add_to_protocol_map::<kiiroo_v2::KiirooV2>(&map, "kiiroo-v2");
   add_to_protocol_map::<kiiroo_v2_vibrator::KiirooV2Vibrator>(&map, "kiiroo-v2-vibrator");
   add_to_protocol_map::<kiiroo_v21::KiirooV21>(&map, "kiiroo-v21");
-  add_to_protocol_map::<kiiroo_v21_initialized::KiirooV21Initialized>(&map, "kiiroo-v21-initialized");
+  add_to_protocol_map::<kiiroo_v21_initialized::KiirooV21Initialized>(
+    &map,
+    "kiiroo-v21-initialized",
+  );
   add_to_protocol_map::<lelof1s::LeloF1s>(&map, "lelo-f1s");
   add_to_protocol_map::<libo_elle::LiboElle>(&map, "libo-elle");
   add_to_protocol_map::<libo_shark::LiboShark>(&map, "libo-shark");
   add_to_protocol_map::<libo_vibes::LiboVibes>(&map, "libo-vibes");
   add_to_protocol_map::<lovehoney_desire::LovehoneyDesire>(&map, "lovehoney-desire");
   add_to_protocol_map::<lovense::Lovense>(&map, "lovense");
-  add_to_protocol_map::<lovense_connect_service::LovenseConnectService>(&map, "lovense-connect-service");
+  add_to_protocol_map::<lovense_connect_service::LovenseConnectService>(
+    &map,
+    "lovense-connect-service",
+  );
   add_to_protocol_map::<lovenuts::LoveNuts>(&map, "lovenuts");
   add_to_protocol_map::<magic_motion_v1::MagicMotionV1>(&map, "magic-motion-1");
   add_to_protocol_map::<magic_motion_v2::MagicMotionV2>(&map, "magic-motion-2");
   add_to_protocol_map::<magic_motion_v3::MagicMotionV3>(&map, "magic-motion-3");
   add_to_protocol_map::<maxpro::Maxpro>(&map, "maxpro");
+  add_to_protocol_map::<mizzzee::MizzZee>(&map, "mizzzee");
   add_to_protocol_map::<motorbunny::Motorbunny>(&map, "motorbunny");
   add_to_protocol_map::<mysteryvibe::MysteryVibe>(&map, "mysteryvibe");
   add_to_protocol_map::<nobra::Nobra>(&map, "nobra");
@@ -102,6 +123,7 @@ pub fn get_default_protocol_map() -> DashMap<String, TryCreateProtocolFunc> {
   add_to_protocol_map::<xinput::XInput>(&map, "xinput");
   add_to_protocol_map::<youcups::Youcups>(&map, "youcups");
   add_to_protocol_map::<youou::Youou>(&map, "youou");
+  add_to_protocol_map::<zalo::Zalo>(&map, "zalo");
   map
 }
 
@@ -390,8 +412,11 @@ pub trait ButtplugProtocolCommandHandler: Send + ButtplugProtocolProperties {
     unimplemented!("Command not implemented for this protocol");
     #[cfg(not(build = "debug"))]
     Box::pin(future::ready(Err(
-      ButtplugDeviceError::UnhandledCommand(format!("Command not implemented for this protocol: {}", command))
-        .into(),
+      ButtplugDeviceError::UnhandledCommand(format!(
+        "Command not implemented for this protocol: {}",
+        command
+      ))
+      .into(),
     )))
   }
 
