@@ -76,7 +76,7 @@ pub fn get_piston_speed(mut distance: f64, mut duration: f64) -> u8 {
     speed = 0f64;
   }
 
-  return speed as u8;
+  speed as u8
 }
 
 impl ButtplugProtocolCommandHandler for VorzeSA {
@@ -189,10 +189,12 @@ impl ButtplugProtocolCommandHandler for VorzeSA {
 #[cfg(all(test, feature = "server"))]
 mod test {
   use crate::{
-    core::messages::{RotateCmd, RotationSubcommand, StopDeviceCmd, VibrateCmd, VibrateSubcommand,
-                     LinearCmd, VectorSubcommand},
+    core::messages::{
+      LinearCmd, RotateCmd, RotationSubcommand, StopDeviceCmd, VectorSubcommand, VibrateCmd,
+      VibrateSubcommand,
+    },
     device::{DeviceImplCommand, DeviceWriteCmd, Endpoint},
-    test::{check_test_recv_empty, check_test_recv_value, new_bluetoothle_test_device},
+    server::comm_managers::test::{check_test_recv_empty, check_test_recv_value, new_bluetoothle_test_device},
     util::async_manager,
   };
 
@@ -272,9 +274,9 @@ mod test {
       let (device, test_device) = new_bluetoothle_test_device("CycSA").await.unwrap();
       let command_receiver = test_device.get_endpoint_receiver(&Endpoint::Tx).unwrap();
       device
-          .parse_message(RotateCmd::new(0, vec![RotationSubcommand::new(0, 0.5, false)]).into())
-          .await
-          .unwrap();
+        .parse_message(RotateCmd::new(0, vec![RotationSubcommand::new(0, 0.5, false)]).into())
+        .await
+        .unwrap();
       check_test_recv_value(
         &command_receiver,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -286,9 +288,9 @@ mod test {
       assert!(check_test_recv_empty(&command_receiver));
 
       device
-          .parse_message(RotateCmd::new(0, vec![RotationSubcommand::new(0, 0.5, true)]).into())
-          .await
-          .unwrap();
+        .parse_message(RotateCmd::new(0, vec![RotationSubcommand::new(0, 0.5, true)]).into())
+        .await
+        .unwrap();
       check_test_recv_value(
         &command_receiver,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -300,9 +302,9 @@ mod test {
       assert!(check_test_recv_empty(&command_receiver));
 
       device
-          .parse_message(StopDeviceCmd::new(0).into())
-          .await
-          .unwrap();
+        .parse_message(StopDeviceCmd::new(0).into())
+        .await
+        .unwrap();
       check_test_recv_value(
         &command_receiver,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -321,23 +323,19 @@ mod test {
       let (device, test_device) = new_bluetoothle_test_device("VorzePiston").await.unwrap();
       let command_receiver = test_device.get_endpoint_receiver(&Endpoint::Tx).unwrap();
       device
-          .parse_message(LinearCmd::new(0, vec![VectorSubcommand::new(0, 150, 0.95)]).into())
-          .await
-          .unwrap();
+        .parse_message(LinearCmd::new(0, vec![VectorSubcommand::new(0, 150, 0.95)]).into())
+        .await
+        .unwrap();
       check_test_recv_value(
         &command_receiver,
-        DeviceImplCommand::Write(DeviceWriteCmd::new(
-          Endpoint::Tx,
-          vec![0x03, 190, 92],
-          true,
-        )),
+        DeviceImplCommand::Write(DeviceWriteCmd::new(Endpoint::Tx, vec![0x03, 190, 92], true)),
       );
       assert!(check_test_recv_empty(&command_receiver));
 
       device
-          .parse_message(LinearCmd::new(0, vec![VectorSubcommand::new(0, 150, 0.95)]).into())
-          .await
-          .unwrap();
+        .parse_message(LinearCmd::new(0, vec![VectorSubcommand::new(0, 150, 0.95)]).into())
+        .await
+        .unwrap();
       check_test_recv_value(
         &command_receiver,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -349,9 +347,9 @@ mod test {
       assert!(check_test_recv_empty(&command_receiver));
 
       device
-          .parse_message(LinearCmd::new(0, vec![VectorSubcommand::new(0, 50, 0.5)]).into())
-          .await
-          .unwrap();
+        .parse_message(LinearCmd::new(0, vec![VectorSubcommand::new(0, 50, 0.5)]).into())
+        .await
+        .unwrap();
       check_test_recv_value(
         &command_receiver,
         DeviceImplCommand::Write(DeviceWriteCmd::new(
@@ -363,9 +361,9 @@ mod test {
       assert!(check_test_recv_empty(&command_receiver));
 
       device
-          .parse_message(StopDeviceCmd::new(0).into())
-          .await
-          .unwrap();
+        .parse_message(StopDeviceCmd::new(0).into())
+        .await
+        .unwrap();
       assert!(check_test_recv_empty(&command_receiver));
     });
   }
