@@ -16,9 +16,6 @@
 extern crate buttplug_derive;
 #[macro_use]
 extern crate strum_macros;
-#[cfg(feature = "thread-pool-runtime")]
-#[macro_use]
-extern crate lazy_static;
 #[cfg(any(feature = "client", feature = "server"))]
 #[macro_use]
 extern crate futures;
@@ -34,5 +31,3 @@ pub mod device;
 #[cfg(feature = "server")]
 pub mod server;
 pub mod util;
-
-pub mod test;
