@@ -1,4 +1,6 @@
-mod lovense_connect_service_device_impl;
 mod lovense_connect_service_comm_manager;
+mod lovense_connect_service_device_impl;
+pub use lovense_connect_service_comm_manager::{
+  LovenseConnectServiceCommunicationManager, LovenseConnectServiceCommunicationManagerBuilder,
+};
 pub use lovense_connect_service_device_impl::LovenseServiceDeviceImpl;
-pub use lovense_connect_service_comm_manager::{LovenseConnectServiceCommunicationManager, LovenseConnectServiceCommunicationManagerBuilder};
\ No newline at end of file
